Changelog
---------
1.3.2 (2019-06-18)
~~~~~~~~~~~~~~~~~~~

- Fixes Travis build error.
  [href]

1.3.1 (2019-06-18)
~~~~~~~~~~~~~~~~~~~

- Changes the return date to only be available on unrestricted, express jobs.
  [href]

- Forces a box count of 1 for restricted, normal jobs.
  [href]

1.3.0 (2019-05-15)
~~~~~~~~~~~~~~~~~~~

- Adds a report for all forms of all municipalities.
  [msom]

1.2.7 (2019-05-14)
~~~~~~~~~~~~~~~~~~~

- Fixes default express dispatch date.
  [msom]

- Fixes express return date.
  [msom]

- Improves the unrestricted scan job form.
  [msom]

1.2.6 (2019-05-14)
~~~~~~~~~~~~~~~~~~~

- Redirect to the login form if an admin/editor modifies itself.
  [msom]

1.2.5 (2019-05-14)
~~~~~~~~~~~~~~~~~~~

- Uses plain buttons instead of dropdowns to add elements.
  [msom]

- Presets the first pickup date of the current year when deleting.
  [msom]

- Changes the scan jobs filter button labels.
  [msom]

- Changes colum titles of the boxes and form daily list.
  [msom]

1.2.4 (2019-05-09)
~~~~~~~~~~~~~~~~~~~

- Presets the return date to the next dispatch date when adding a scan job
  (unrestricted).
  [msom]

1.2.3 (2019-05-09)
~~~~~~~~~~~~~~~~~~~

- Sends an email to contacts if an admin creates a scan job.
  [msom]

1.2.2 (2019-05-07)
~~~~~~~~~~~~~~~~~~~

- Shows the totals in the daily lists in the table body instead of the footer.
  [msom]

- Hides the deadline callout for express scan jobs.
  [msom]

- Allows editors to manage themselves.
  [msom]

- Uses a mail separate text for express scan jobs.
  [msom]

1.2.1 (2019-05-02)
~~~~~~~~~~~~~~~~~~~

- Fixes permission settings of user manual.
  [msom]

1.2.0 (2019-05-01)
~~~~~~~~~~~~~~~~~~~

- Adds a user manual.
  [msom]

1.1.7 (2019-04-30)
~~~~~~~~~~~~~~~~~~~

- Reworks municipality data import.
  [msom]

- Fixes dispatch and return note not present in delivery note.
  [msom]

- Increments delivery numbers by municipality, not globally.
  [msom]

1.1.6 (2019-04-30)
~~~~~~~~~~~~~~~~~~~

- Removes legacy sentry parameter.
  [msom]

- Enables sentry in CLI commands.
  [msom]

- Replaces Raven JS with Sentry.
  [msom]

1.1.5 (2019-04-29)
~~~~~~~~~~~~~~~~~~~

- Removes unused dependency.
  [msom]

1.1.4 (2019-04-26)
~~~~~~~~~~~~~~~~~~~

- Adjusts invoice export.
  [msom]

- Hides old pickup dates in the municipality view.
  [msom]

1.1.3 (2019-04-24)
~~~~~~~~~~~~~~~~~~~

- Adjusts invoice export.
  [msom]

- Uses the year of the end date from the filter as column header reference.
  [msom]

- Visually equalizes daily lists.
  [msom]

- Fixes daily list boxes view.
  [msom]

- Fixes delivery note totals.
  [msom]

1.1.2 (2019-04-23)
~~~~~~~~~~~~~~~~~~~

- Improves CSV handling.
  [msom]

1.1.1 (2019-04-23)
~~~~~~~~~~~~~~~~~~~

- Removes the YubiKey field from the login form.
  [msom]

1.1.0 (2019-04-22)
~~~~~~~~~~~~~~~~~~~

- Allows to manage admins.
  [msom]

- Makes municipality list sortable.
  [msom]

- Makes user list sortable.
  [msom]

1.0.0 (2019-04-11)
~~~~~~~~~~~~~~~~~~~

- Removes iFrame support.
  [msom]

0.0.9 (2019-04-08)
~~~~~~~~~~~~~~~~~~~

- Removes VAT from invoices.
  [msom]

0.0.8 (2019-04-02)
~~~~~~~~~~~~~~~~~~~

- Allows the application to be displayed within an iFrame.
  [msom]

0.0.7 (2019-04-01)
~~~~~~~~~~~~~~~~~~~

- Removes always run option on upgrade step.
  [msom]

0.0.6 (2019-03-29)
~~~~~~~~~~~~~~~~~~~

- Adds payment types.
  [msom]

0.0.5 (2019-03-28)
~~~~~~~~~~~~~~~~~~~

- Adds datetime picker.
  [msom]

- Directly returns the invoices CSV.
  [msom]

- Allows to create invoices for all municipalities.
  [msom]

- Colorizes the daily list boxes view.
  [msom]

0.0.4 (2019-03-13)
~~~~~~~~~~~~~~~~~~~

- Fixes municipality and users templates.
  [msom]

- Orders pickup dates when creating scan jobs as regular users.
  [msom]

- Fixes home page redirection for users without a municipality.
  [msom]

- Updates scan job labels.
  [msom]

0.0.3 (2019-03-11)
~~~~~~~~~~~~~~~~~~~

- Update deploy keys.
  [msom]

0.0.2 (2019-03-11)
~~~~~~~~~~~~~~~~~~~

- First version.
  [msom]

0.0.1 (2019-01-28)
~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [msom]
